@@ -8,7 +8,7 @@ from sphinx.util.nodes import set_source_info
 from sphinx.util import logging
 from docutils import nodes
 
-logger = logging.getLogger(__name__)
+_logger = logging.getLogger(__name__)
 
 
 def setup(app):
@@ -38,9 +38,8 @@ def _ev_doctree_read__extract_tasknodes(app, doctree):
                 integrators = n.integrators,
             ))
             n.replace_self([])
-    except Exception:
-        logger.exception(f'{docname}: cannot extract task nodes')
-        raise
+    except OpenTrainingError as e:
+        log_and_swallow_error(e, _logger)
         
 class _TaskNode(nodes.Element):
     def __init__(self, path, dependencies,
